@@ -1,13 +1,11 @@
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 1.18 $
-# Date: $Date: 2004/06/18 21:36:55 $
+# $Id: en.py 10169 2025-06-16 10:05:35Z milde $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 # New language mappings are welcome.  Before doing a new translation, please
-# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
-# translated for each language: one in docutils/languages, the other in
-# docutils/parsers/rst/languages.
+# read <https://docutils.sourceforge.io/docs/howto/i18n.html>.
+# Two files must be translated for each language: one in docutils/languages,
+# the other in docutils/parsers/rst/languages.
 
 """
 English-language mappings for language-dependent features of
@@ -28,39 +26,52 @@ directives = {
       'note': 'note',
       'tip': 'tip',
       'warning': 'warning',
-      'admonition': 'admonition',
+      'admonition': 'admonition',  # advice/advisory/remark, not reprimand
       'sidebar': 'sidebar',
       'topic': 'topic',
       'line-block': 'line-block',
       'parsed-literal': 'parsed-literal',
+      'code': 'code',
+      'code-block': 'code',
+      'sourcecode': 'code',
+      'math': 'math',
       'rubric': 'rubric',
       'epigraph': 'epigraph',
       'highlights': 'highlights',
       'pull-quote': 'pull-quote',
-      #'questions': 'questions',
+      'compound': 'compound',
+      'container': 'container',
       'table': 'table',
       'csv-table': 'csv-table',
-      #'qa': 'questions',
-      #'faq': 'questions',
+      'list-table': 'list-table',
       'meta': 'meta',
-      #'imagemap': 'imagemap',
+      # 'imagemap': 'imagemap',
       'image': 'image',
       'figure': 'figure',
       'include': 'include',
       'raw': 'raw',
       'replace': 'replace',
       'unicode': 'unicode',
+      'date': 'date',
       'class': 'class',
+      'rst-class': 'class',  # Sphinx compatibility alias
       'role': 'role',
+      'default-role': 'default-role',
+      'title': 'title',
       'contents': 'contents',
       'sectnum': 'sectnum',
       'section-numbering': 'sectnum',
-      #'footnotes': 'footnotes',
-      #'citations': 'citations',
+      'header': 'header',
+      'footer': 'footer',
+      # 'footnotes': 'footnotes',
+      # 'citations': 'citations',
       'target-notes': 'target-notes',
       'restructuredtext-test-directive': 'restructuredtext-test-directive'}
-"""English name to registered (in directives/__init__.py) directive name
-mapping."""
+"""Mapping of English directive name to registered directive names
+
+Cf. https://docutils.sourceforge.io/docs/ref/rst/directives.html
+and `_directive_registry` in ``directives/__init__.py``.
+"""
 
 roles = {
     # language-dependent: fixed
@@ -68,8 +79,15 @@ roles = {
     'ab': 'abbreviation',
     'acronym': 'acronym',
     'ac': 'acronym',
-    'index': 'index',
-    'i': 'index',
+    'code': 'code',
+    'emphasis': 'emphasis',
+    'literal': 'literal',
+    'math': 'math',
+    'pep-reference': 'pep-reference',
+    'pep': 'pep-reference',
+    'rfc-reference': 'rfc-reference',
+    'rfc': 'rfc-reference',
+    'strong': 'strong',
     'subscript': 'subscript',
     'sub': 'subscript',
     'superscript': 'superscript',
@@ -77,21 +95,21 @@ roles = {
     'title-reference': 'title-reference',
     'title': 'title-reference',
     't': 'title-reference',
-    'pep-reference': 'pep-reference',
-    'pep': 'pep-reference',
-    'rfc-reference': 'rfc-reference',
-    'rfc': 'rfc-reference',
-    'emphasis': 'emphasis',
-    'strong': 'strong',
-    'literal': 'literal',
-    'named-reference': 'named-reference',
+    'raw': 'raw',
+    # the following roles are not implemented in Docutils
+    'index': 'index',
+    'i': 'index',
     'anonymous-reference': 'anonymous-reference',
-    'footnote-reference': 'footnote-reference',
     'citation-reference': 'citation-reference',
+    'footnote-reference': 'footnote-reference',
+    'named-reference': 'named-reference',
     'substitution-reference': 'substitution-reference',
-    'target': 'target',
     'uri-reference': 'uri-reference',
     'uri': 'uri-reference',
-    'url': 'uri-reference',}
+    'url': 'uri-reference',
+    'target': 'target',
+    }
 """Mapping of English role names to canonical role names for interpreted text.
+
+Cf. https://docutils.sourceforge.io/docs/ref/rst/roles.html
 """
