@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 
-# $Id: test_option_lists.py 9037 2022-03-05 23:31:10Z milde $
+# $Id: test_option_lists.py 9473 2023-11-13 18:29:27Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -8,15 +8,34 @@
 Tests for states.py.
 """
 
+from pathlib import Path
+import sys
+import unittest
+
 if __name__ == '__main__':
-    import __init__  # noqa: F401
-from test_parsers import DocutilsTestSupport
+    # prepend the "docutils root" to the Python library path
+    # so we import the local `docutils` package.
+    sys.path.insert(0, str(Path(__file__).resolve().parents[3]))
+
+from docutils.frontend import get_default_settings
+from docutils.parsers.rst import Parser
+from docutils.utils import new_document
 
 
-def suite():
-    s = DocutilsTestSupport.ParserTestSuite()
-    s.generateTests(totest)
-    return s
+class ParserTestCase(unittest.TestCase):
+    maxDiff = None
+
+    def test_parser(self):
+        parser = Parser()
+        settings = get_default_settings(Parser)
+        settings.warning_stream = ''
+        for name, cases in totest.items():
+            for casenum, (case_input, case_expected) in enumerate(cases):
+                with self.subTest(id=f'totest[{name!r}][{casenum}]'):
+                    document = new_document('test data', settings.copy())
+                    parser.parse(case_input, document)
+                    output = document.pformat()
+                    self.assertEqual(case_expected, output)
 
 
 totest = {}
@@ -690,7 +709,11 @@ Complex optargs:
                         Option argument containing delimiter ``=``.
 -f <[path]filename>     Send output to file.
 -d <src dest>           Use diff from <src> to <dest>.
---bogus=<x y z>         Bogus 3D coordinates.
+--point=<x y z>         3D coordinates.
+--vector <"x, y, z">    Another option expecting 3 arguments.
+--cvs=<'a[, b[, ...]]]'>
+                        Comma separated arguments.
+-g <a, , c>             Complex arg with empty list element.
 """,
 """\
 <document source="test data">
@@ -760,16 +783,61 @@ Complex optargs:
             <option_group>
                 <option>
                     <option_string>
-                        --bogus
+                        --point
                     <option_argument delimiter="=">
                         <x y z>
             <description>
                 <paragraph>
-                    Bogus 3D coordinates.
+                    3D coordinates.
+        <option_list_item>
+            <option_group>
+                <option>
+                    <option_string>
+                        --vector
+                    <option_argument delimiter=" ">
+                        <"x, y, z">
+            <description>
+                <paragraph>
+                    Another option expecting 3 arguments.
+        <option_list_item>
+            <option_group>
+                <option>
+                    <option_string>
+                        --cvs
+                    <option_argument delimiter="=">
+                        <'a[, b[, ...]]]'>
+            <description>
+                <paragraph>
+                    Comma separated arguments.
+        <option_list_item>
+            <option_group>
+                <option>
+                    <option_string>
+                        -g
+                    <option_argument delimiter=" ">
+                        <a, , c>
+            <description>
+                <paragraph>
+                    Complex arg with empty list element.
+"""],
+["""\
+Incorrect option syntax → no option list.
+
+-f, , --force   Empty synonym.
+-f <a, , b      Unbalanced angle bracket.
+-f a, , b>      Unbalanced angle bracket.
+""",
+"""\
+<document source="test data">
+    <paragraph>
+        Incorrect option syntax → no option list.
+    <paragraph>
+        -f, , --force   Empty synonym.
+        -f <a, , b      Unbalanced angle bracket.
+        -f a, , b>      Unbalanced angle bracket.
 """],
 ]
 
 
 if __name__ == '__main__':
-    import unittest
-    unittest.main(defaultTest='suite')
+    unittest.main()
